@@ -149,7 +149,7 @@ def remove_whitespaces(source: str) -> str:
     return "\n".join(lines)
 
 
-def get_docstring_arg_type(t: str, is_list: bool = False, is_pyayiin_type: bool = False):
+def get_docstring_arg_type(t: str, is_list: bool = False, is_pyAyiin_type: bool = False):
     if t in CORE_TYPES:
         if t == "long":
             return "``int`` ``64-bit``"
@@ -369,7 +369,7 @@ def start(format: bool = False):
                 "{}{}: {}".format(
                     arg_name,
                     " (optional)".format(flag_number) if is_optional else "",
-                    get_docstring_arg_type(arg_type, is_pyayiin_type=c.namespace == "pyAyiin")
+                    get_docstring_arg_type(arg_type, is_pyAyiin_type=c.namespace == "pyAyiin")
                 )
             )
 
