@@ -17,16 +17,14 @@ import logging
 import sys
 import time
 
-from . import raw
 from pyAyiin.xd import GenSession
 from pyAyiin.methods import *
 from pyAyiin.pyrogram import AyiinMethods
-from pyAyiin.telethon.ayiin import *
 
 
 __copyright__ = "Copyright (C) 2022-present AyiinXd <https://github.com/AyiinXd>"
 __license__ = "GNU General Public License v3.0 (GPL-3.0)"
-__version__ = "0.0.3"
+__version__ = "0.0.7"
 
 
 adB = AyiinDB()
@@ -38,10 +36,6 @@ class PyroXd(AyiinMethods, GenSession, Methods):
     pass
 
 
-class TeleXd(AyiinMethod, GenSession, Methods):
-    pass
-
-
 suc_msg = (f"""
 ========================×========================
               Credit Py-Ayiin {__version__}
@@ -54,7 +48,8 @@ run_as_module = False
 if sys.argv[0] == "-m":
     run_as_module = True
 
-    print(__copyright__ + "\n" + __license__ + "\n")
+    print("\n\n" + __copyright__ + "\n" + __license__)
+    print(suc_msg)
 else:
-    print(__copyright__ + "\n" + __license__ + "\n")
+    print("\n\n" + __copyright__ + "\n" + __license__)
     print(suc_msg)
