@@ -1,4 +1,4 @@
-from ._wrappers import eod, eor
+from ._wrappers import Wrappers
 from .func import Function
 from .misc import Misc
 from .pastebin import PasteBin, paste, post, s_paste
@@ -12,5 +12,6 @@ class AyiinMethods(
     Misc,
     ToolBot,
     Tools,
+    Wrappers,
 ):
     pass
