@@ -20,4 +20,4 @@ from .tl_object import TLObject
 
 class List(TList[Any], TLObject):
     def __repr__(self) -> str:
-        return f"pyrogram.raw.core.List([{','.join(TLObject.__repr__(i) for i in self)}])"
+        return f"pyAyiin.raw.core.List([{','.join(TLObject.__repr__(i) for i in self)}])"
